==> payara-embedded-all-4.1.1.164-sources.jar: com/sun/enterprise/container/common/spi/util/JavaEEIOUtils.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2010-2014 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.enterprise.container.common.spi.util;

import org.jvnet.hk2.annotations.Contract;

import com.sun.enterprise.container.common.spi.util.GlassFishOutputStreamHandler;

import java.io.*;

/**
 * A contract that defines a set of methods to serialize / deserialze Java EE
 *  objects (even if they are not directly serializable).
 *
 * Some of the objects that are expected to be serialized / de-serialized are
 *   a) Local EJB references
 *   b) EJB Handles
 *   c) JNDI (sub) contexts
 *   d) (Non serializable) StatefulSessionBeans
 *
 * @author Mahesh Kannan
 * 
 */
@Contract
public interface JavaEEIOUtils {
	
    public ObjectInputStream createObjectInputStream(InputStream is, boolean resolveObject, ClassLoader loader)
	    throws Exception;

    public ObjectOutputStream createObjectOutputStream(OutputStream os, boolean replaceObject)
	    throws IOException;

    public byte[] serializeObject(Object obj, boolean replaceObject)
	    throws java.io.IOException;

    public Object deserializeObject(byte[] data, boolean resolveObject, ClassLoader appClassLoader)
            throws Exception;
    
    public void addGlassFishOutputStreamHandler(GlassFishOutputStreamHandler handler);
    
    public void removeGlassFishOutputStreamHandler(GlassFishOutputStreamHandler handler);
    
    public void addGlassFishInputStreamHandler(GlassFishInputStreamHandler handler);
    
    public void removeGlassFishInputStreamHandler(GlassFishInputStreamHandler handler);

}

==> payara-embedded-all-5.2020.4-sources.jar: com/sun/enterprise/container/common/spi/util/JavaEEIOUtils.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2010-2014 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
// Portions Copyright [2016-2018] [Payara Foundation and/or its affiliates]

package com.sun.enterprise.container.common.spi.util;

import org.jvnet.hk2.annotations.Contract;

import java.io.*;

/**
 * A contract that defines a set of methods to serialize / deserialze Java EE
 *  objects (even if they are not directly serializable).
 *
 * Some of the objects that are expected to be serialized / de-serialized are
 *   a) Local EJB references
 *   b) EJB Handles
 *   c) JNDI (sub) contexts
 *   d) (Non serializable) StatefulSessionBeans
 *
 * @author Mahesh Kannan
 *
 */
@Contract
public interface JavaEEIOUtils {

    ObjectInputStream createObjectInputStream(InputStream is, boolean resolveObject, ClassLoader loader, long uniqueId)
	    throws Exception;

    ObjectOutputStream createObjectOutputStream(OutputStream os, boolean replaceObject)
	    throws IOException;

    byte[] serializeObject(Object obj, boolean replaceObject)
	    throws java.io.IOException;

    Object deserializeObject(byte[] data, boolean resolveObject, ClassLoader appClassLoader)
            throws Exception;
    Object deserializeObject(byte[] data, boolean resolveObject, ClassLoader appClassLoader, long uniqueId)
            throws Exception;

    void addGlassFishOutputStreamHandler(GlassFishOutputStreamHandler handler);

    void removeGlassFishOutputStreamHandler(GlassFishOutputStreamHandler handler);

    void addGlassFishInputStreamHandler(GlassFishInputStreamHandler handler);

    void removeGlassFishInputStreamHandler(GlassFishInputStreamHandler handler);

}
